A sentence naming what happened and, where there is one, what to do.
@override String get message => '$method on $table expected at most one row but saw at least $seen. ' 'Use first() to take the first row of an ordered query.';