bulkOptions property
MssqlBulkOptions?
bulkOptions
final
The BCP hints that actually ran, when strategy is bulkCopy.
Implementation
final MssqlBulkOptions? bulkOptions;
The BCP hints that actually ran, when strategy is bulkCopy.
final MssqlBulkOptions? bulkOptions;