rows property
Stored rows, in input order when mappedToInput is true.
Empty when readback was not requested or not possible. That is not "nothing was inserted" — see insertedRows.
Implementation
final List<TRow> rows;
Stored rows, in input order when mappedToInput is true.
Empty when readback was not requested or not possible. That is not "nothing was inserted" — see insertedRows.
final List<TRow> rows;