MssqlCursorPage<TRow> class

One keyset page, with cursors for the neighbouring pages.

Annotations
  • @immutable

Constructors

MssqlCursorPage({required List<TRow> rows, required bool hasMore, MssqlCursor? next, MssqlCursor? previous})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
More rows exist in the direction this call walked.
final
isEmpty bool
no setter
isNotEmpty bool
no setter
next MssqlCursor?
Pass to cursorPage(after: next) for the following page in user order.
final
previous MssqlCursor?
Pass to cursorPage(before: previous) for the preceding page.
final
rows List<TRow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited