MssqlDateBucketUnit enum
The width unit of a MssqlDateBucket.
Values
- year → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('year') - quarter → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('quarter') - month → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('month') - week → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('week') - day → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('day') - hour → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('hour') - minute → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('minute') - second → const MssqlDateBucketUnit
-
const MssqlDateBucketUnit('second')
Properties
- datePart → String
-
SQL Server
datepartkeyword.final - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MssqlDateBucketUnit> - A constant List of the values in this enum, in order of their declaration.