MssqlDatePart enum

Date or time component used by comparison helpers.

Inheritance
Available extensions

Values

date → const MssqlDatePart

The date alone, with the time discarded.

year → const MssqlDatePart
month → const MssqlDatePart
day → const MssqlDatePart
time → const MssqlDatePart

The time of day, with the date discarded.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MssqlDatePart>
A constant List of the values in this enum, in order of their declaration.