included property

List<MssqlRelation<TRow, Object?>> included
final

Relations this query will load after the parent rows, in call order.

Stored on the query rather than on MssqlQueryState because MssqlRelation is invariant in its parent type and a List of MssqlRelation<Object?, Object?> cannot hold MssqlRelation<Order, …> without a cast that fails at runtime.

Implementation

final List<MssqlRelation<TRow, Object?>> included;