when method
Rebuilds this query through build only when test is true.
Implementation
S when(bool test, S Function(S query) build) {
if (!test) return _self;
return build(_self);
}
Rebuilds this query through build only when test is true.
S when(bool test, S Function(S query) build) {
if (!test) return _self;
return build(_self);
}