eqCol method
Compares this expression to another column rather than to a value.
Implementation
MssqlCondition eqCol(String identifier) =>
MssqlComparison(this, '=', Col(identifier));
Compares this expression to another column rather than to a value.
MssqlCondition eqCol(String identifier) =>
MssqlComparison(this, '=', Col(identifier));