MssqlGraphRelation class
One named relation and the graph nodes to write along it.
- Annotations
-
- @immutable
Constructors
-
MssqlGraphRelation(MssqlRelation<
Object?, Object?> relation, List<MssqlGraphInsert< nodes)Object?> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ List<
MssqlGraphInsert< Object?> > -
final
-
relation
→ MssqlRelation<
Object?, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited