MssqlMissingOutputException class

Raised when a procedure did not return an OUTPUT parameter the file named.

Inheritance

Constructors

MssqlMissingOutputException({required String procedure, required String parameter})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A sentence naming what happened and, where there is one, what to do.
no setteroverride
parameter String
final
procedure String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited