message property
String
get
message
A sentence naming what happened and, where there is one, what to do.
Implementation
String get message;
A sentence naming what happened and, where there is one, what to do.
String get message;