returnsRows property
bool
get
returnsRows
Whether the rows come back as a result set rather than going into a table.
Implementation
bool get returnsRows => into == null;
Whether the rows come back as a result set rather than going into a table.
bool get returnsRows => into == null;