MssqlOutputColumn class

One column of an OUTPUT clause.

Annotations
  • @immutable

Constructors

MssqlOutputColumn(MssqlOutputSource source, String column, {String? as})
const
MssqlOutputColumn.deleted(String column, {String? as})
The column's value before the write.
const
MssqlOutputColumn.inserted(String column, {String? as})
The column's value after the write.
const

Properties

as → String?
The result name. Null keeps the column's own name.
final
column → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → MssqlOutputSource
final
sql → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited