MssqlOutputTarget.variable constructor

MssqlOutputTarget.variable(
  1. String name, {
  2. Iterable<String> columns = const <String>[],
})

A DECLARE @name TABLE (…) variable in the same batch.

The name is checked against SQL Server's rule for a regular variable rather than quoted, because @ is part of the name and a quoted identifier is not a variable.

Implementation

MssqlOutputTarget.variable(
  String name, {
  Iterable<String> columns = const <String>[],
}) : quoted = _checkedVariable(name),
     columns = List<String>.unmodifiable(columns);