capabilities property
Shared dialect resolution for this database, or the process-wide cache.
Implementation
final MssqlCapabilityCache? capabilities;
Shared dialect resolution for this database, or the process-wide cache.
final MssqlCapabilityCache? capabilities;