changes property
Committed-write hub for MssqlWatchStrategy.localWrites, or null when this context was not created by an MssqlAppDatabase.
Implementation
final MssqlChangeHub? changes;
Committed-write hub for MssqlWatchStrategy.localWrites, or null when this context was not created by an MssqlAppDatabase.
final MssqlChangeHub? changes;