resolveDialect method

Future<MssqlDialect> resolveDialect()

The dialect of the current database, asking the server at most once.

dialect is the compile-time default when the server has not been asked yet. Terminals await this so a 2008-compatible database does not receive OFFSET … FETCH.

Implementation

Future<MssqlDialect> resolveDialect() {
  final fixed = _fixedDialect;
  if (fixed != null) return Future<MssqlDialect>.value(fixed);
  return (capabilities ?? MssqlCapabilityCache.shared).resolve(session);
}