roundTrips property
Network round-trips this event represents.
One statement is one round-trip. A cached procedure describe that is skipped is not a round-trip. This is not "how many SQL strings were built".
Implementation
final int? roundTrips;
Network round-trips this event represents.
One statement is one round-trip. A cached procedure describe that is skipped is not a round-trip. This is not "how many SQL strings were built".
final int? roundTrips;