changes property
Committed-write hub, or null when this repository is not from an AppDatabase.
Implementation
final MssqlChangeHub? changes;
Committed-write hub, or null when this repository is not from an AppDatabase.
final MssqlChangeHub? changes;