key property
The key or predicate description that found nothing. Null when the query was a filter rather than a key lookup.
Implementation
final Object? key;
The key or predicate description that found nothing. Null when the query was a filter rather than a key lookup.
final Object? key;