MssqlSchemaDifference class
One difference between a schema snapshot and the live database.
- Annotations
-
- @immutable
Constructors
- MssqlSchemaDifference({required String table, required MssqlDifferenceKind kind, required MssqlDifferenceSeverity severity, required String expected, required String actual, required String remedy, String? column})
-
const
Properties
- actual → String
-
final
- column → String?
-
final
- expected → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBreaking → bool
-
no setter
- kind → MssqlDifferenceKind
-
final
- remedy → String
-
What to do about it, in a sentence.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → MssqlDifferenceSeverity
-
final
- table → String
-
final
Methods
-
describe(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited