MssqlSchemaReport class

Everything the check found.

Annotations
  • @immutable

Constructors

MssqlSchemaReport(List<MssqlSchemaDifference> differences)

Properties

breaking → List<MssqlSchemaDifference>
no setter
differences → List<MssqlSchemaDifference>
final
hasBreakingChanges → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isClean → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() → String
A readable summary.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited