build property
The predicate. Null means "add nothing" — useful for a scope whose condition depends on state that may be absent.
Implementation
final MssqlCondition? Function() build;
The predicate. Null means "add nothing" — useful for a scope whose condition depends on state that may be absent.
final MssqlCondition? Function() build;