quoted property
String
get
quoted
[dbo].[Orders], for a query that gave the source no alias.
Implementation
String get quoted => MssqlSql.quoteMultipartIdentifier(parts);
[dbo].[Orders], for a query that gave the source no alias.
String get quoted => MssqlSql.quoteMultipartIdentifier(parts);