bind method
Records that source appears in this statement as alias.
alias is the already-quoted identifier the query wrote.
Implementation
void bind(MssqlSourceRef source, String alias) => _aliases[source] = alias;
Records that source appears in this statement as alias.
alias is the already-quoted identifier the query wrote.
void bind(MssqlSourceRef source, String alias) => _aliases[source] = alias;