parameters property
The values to bind, keyed by parameter name without the leading @.
Names are an implementation detail of one MssqlStatement; depend on this map, not on the names in sql.
Implementation
final Map<String, Object?> parameters;
The values to bind, keyed by parameter name without the leading @.
Names are an implementation detail of one MssqlStatement; depend on this map, not on the names in sql.
final Map<String, Object?> parameters;