MssqlTypeFamily enum

Coarse SQL type families used for compatibility checks.

Inheritance
Available extensions

Values

boolean → const MssqlTypeFamily
integer → const MssqlTypeFamily
exactNumeric → const MssqlTypeFamily

decimal, numeric, money, smallmoney: exact, with a scale.

approximateNumeric → const MssqlTypeFamily

real, float: binary floating point.

text → const MssqlTypeFamily
binary → const MssqlTypeFamily
temporal → const MssqlTypeFamily
guid → const MssqlTypeFamily
xml → const MssqlTypeFamily

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MssqlTypeFamily>
A constant List of the values in this enum, in order of their declaration.