MssqlUnexpectedResultSetException class

Raised when a procedure returned a different number of result sets than the generated wrapper declared.

Inheritance

Constructors

MssqlUnexpectedResultSetException({required String procedure, required int expected, required int actual})
const

Properties

actual int
final
expected int
final
hashCode int
The hash code for this object.
no setterinherited
message String
A sentence naming what happened and, where there is one, what to do.
no setteroverride
procedure String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited