rows property
The stored rows, when the write read them back. Empty otherwise, which is not the same as "the write matched nothing" — check affectedRows.
Implementation
final List<MssqlRow> rows;
The stored rows, when the write read them back. Empty otherwise, which is not the same as "the write matched nothing" — check affectedRows.
final List<MssqlRow> rows;