mssqlTruncatedRelationsKey top-level constant

String const mssqlTruncatedRelationsKey

Map key MssqlTableBinding.applyRelations uses for truncated names.

Generated withRelations reads this and does not treat it as a relation that was loaded. A collision with a real relation named this way is refused at generation time.

Implementation

const String mssqlTruncatedRelationsKey = '__mssql_truncated';