MssqlJoin class

Annotations
  • @immutable

Constructors

MssqlJoin(MssqlJoinKind kind, MssqlSource source, MssqlCondition? on)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → MssqlJoinKind
final
on → MssqlCondition?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → MssqlSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited