MssqlJoinKind enum

The join kinds SQL Server supports.

Inheritance
Available extensions

Values

inner → const MssqlJoinKind
const MssqlJoinKind('INNER JOIN')
left → const MssqlJoinKind
const MssqlJoinKind('LEFT JOIN')
const MssqlJoinKind('RIGHT JOIN')
full → const MssqlJoinKind
const MssqlJoinKind('FULL JOIN')
cross → const MssqlJoinKind
const MssqlJoinKind('CROSS JOIN')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MssqlJoinKind>
A constant List of the values in this enum, in order of their declaration.