projectionCount property
int?
get
projectionCount
Known number of selected expressions, or null when it cannot be proven.
Implementation
int? get projectionCount;
Known number of selected expressions, or null when it cannot be proven.
int? get projectionCount;