MssqlSource class

A table or view, optionally aliased.

Annotations
  • @immutable

Constructors

MssqlSource(String identifier, {String? alias, MssqlSourceRef? ref})
MssqlSource.parts(List<String> parts, {String? alias, MssqlSourceRef? ref})
A source whose parts are already separated.
MssqlSource.subquery(MssqlSelectQuery query, {required String as})
factory

Properties

alias → String?
final
hashCode → int
The hash code for this object.
no setterinherited
query → MssqlSelectQuery?
final
quoted → String
final
ref → MssqlSourceRef?
Which source this is, for the columns that belong to it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compile(MssqlParameterAllocator parameters, MssqlDialect dialect) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited