MssqlForeignKeySchema class

Annotations
  • @immutable

Constructors

MssqlForeignKeySchema({required String name, required List<String> columns, required String referencedSchema, required String referencedTable, required List<String> referencedColumns})

Properties

columns List<String>
The columns on this table, paired positionally with referencedColumns.
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
referencedColumns List<String>
final
referencedQualifiedName String
no setter
referencedSchema String
final
referencedTable String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited