qualifiedName property
String
get
qualifiedName
schema.name, unquoted, as a configuration file would write it.
Implementation
String get qualifiedName => '$schema.$name';
schema.name, unquoted, as a configuration file would write it.
String get qualifiedName => '$schema.$name';