AbsentField<T> class
final
The column is not named in the statement.
Constructors
- AbsentField()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAbsent → bool
-
Whether this is AbsentField.
no setterinherited
- isPresent → bool
-
Whether this is ValueField.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The carried value. Throws if this is AbsentField.
no setterinherited
- valueOrNull → T?
-
The value, or null when absent.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override