MssqlAggregateFunction enum
Aggregate functions emitted by the query builder.
Values
- sum → const MssqlAggregateFunction
-
const MssqlAggregateFunction('SUM') - avg → const MssqlAggregateFunction
-
const MssqlAggregateFunction('AVG') - min → const MssqlAggregateFunction
-
const MssqlAggregateFunction('MIN') - max → const MssqlAggregateFunction
-
const MssqlAggregateFunction('MAX') - count → const MssqlAggregateFunction
-
const MssqlAggregateFunction('COUNT') - countBig → const MssqlAggregateFunction
-
COUNT_BIG, which returnsbigintinstead ofint.const MssqlAggregateFunction('COUNT_BIG')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sql → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MssqlAggregateFunction> - A constant List of the values in this enum, in order of their declaration.