message property
A sentence naming what happened and, where there is one, what to do.
Implementation
@override
String get message =>
'$operation on $table${key == null ? '' : ' (key $key)'} matched no row '
'with the expected version. The row was changed or deleted by someone '
'else; re-read it and decide what to keep.';