MssqlDateDiffUnit enum

The unit DATEDIFF counts in.

Inheritance
Available extensions

Values

year → const MssqlDateDiffUnit
const MssqlDateDiffUnit('year')
quarter → const MssqlDateDiffUnit
const MssqlDateDiffUnit('quarter')
month → const MssqlDateDiffUnit
const MssqlDateDiffUnit('month')
week → const MssqlDateDiffUnit
const MssqlDateDiffUnit('week')
day → const MssqlDateDiffUnit
const MssqlDateDiffUnit('day')
hour → const MssqlDateDiffUnit
const MssqlDateDiffUnit('hour')
minute → const MssqlDateDiffUnit
const MssqlDateDiffUnit('minute')
second → const MssqlDateDiffUnit

Can overflow after roughly 68 years because DATEDIFF returns int.

const MssqlDateDiffUnit('second')

Properties

datePart String
SQL Server datepart keyword.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MssqlDateDiffUnit>
A constant List of the values in this enum, in order of their declaration.