MssqlFrameBound class

One end of a MssqlWindowFrame.

Annotations
  • @immutable

Constructors

MssqlFrameBound.following(int rows)
n FOLLOWING.
factory
MssqlFrameBound.preceding(int rows)
n PRECEDING.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → int?
How many rows, for the two offset forms; null for the rest.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
Clause built from a validated integer offset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

currentRow → const MssqlFrameBound
CURRENT ROW.
unboundedFollowing → const MssqlFrameBound
UNBOUNDED FOLLOWING: to the end of the partition.
unboundedPreceding → const MssqlFrameBound
UNBOUNDED PRECEDING: from the start of the partition.