MssqlGraphWriter<TRow> class
Explicit multi-table insert: belongsTo first, parent identity, then children, one transaction, no cascade delete.
- Annotations
-
- @immutable
Constructors
-
MssqlGraphWriter(MssqlSession session, {required MssqlTableBinding<
TRow> binding, required MssqlDialect dialect, MssqlClock clock = MssqlClock.serverUtc, MssqlChangeHub? changes})
Properties
-
binding
→ MssqlTableBinding<
TRow> -
final
- changes → MssqlChangeHub?
-
final
- clock → MssqlClock
-
final
- dialect → MssqlDialect
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → MssqlSession
-
final
Methods
-
createGraph(
MssqlGraphInsert< TRow> graph, {MssqlCycleWrite cycle = MssqlCycleWrite.refuse}) → Future<TRow> -
Inserts
graphand returns the stored root with defaults applied. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited