defaultValues method

MssqlInsert defaultValues()

INSERT INTO … DEFAULT VALUES: every column takes its own default.

The only way to insert into a table whose columns are all identity, computed or defaulted. Writing VALUES () is not legal T-SQL, and binding nulls instead would write nulls rather than defaults.

Implementation

MssqlInsert defaultValues() =>
    MssqlInsert._(source, assignments, output, true);