MssqlInsertSelect class
An INSERT ... SELECT statement.
- Available extensions
- Annotations
-
- @immutable
Properties
-
columns
→ List<
String> -
final
-
ctes
→ List<
MssqlCte> -
The
WITHclause of the whole statement.final - hashCode → int
-
The hash code for this object.
no setterinherited
- output → MssqlOutputClause?
-
final
- query → MssqlSelectQuery
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → MssqlSource
-
final
Methods
-
compile(
{MssqlDialect dialect = MssqlDialect.sql2012}) → MssqlStatement -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
returning(
MssqlOutputClause clause) → MssqlInsertSelect -
Reports the written rows through an
OUTPUTclause. -
run(
MssqlSession session, {MssqlDialect dialect = MssqlDialect.sql2012, Duration? timeout}) → Future< int> -
Available on MssqlInsertSelect, provided by the MssqlInsertSelectExecution extension
-
toString(
) → String -
A string representation of this object.
inherited
-
withExpression(
MssqlCte cte) → MssqlInsertSelect - Adds a common table expression to the statement.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited