MssqlOrder class
One term of an ORDER BY.
Constructors
- MssqlOrder(MssqlExpression expression, {required bool descending, MssqlNulls? nulls})
-
const
Properties
- descending → bool
-
final
- expression → MssqlExpression
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nulls → MssqlNulls?
-
Null keeps SQL Server's own rule (NULL is lowest).
final
- nullsFirst → MssqlOrder
-
Same term with NULLs before every other value.
no setter
- nullsLast → MssqlOrder
-
Same term with NULLs after every other value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited