MssqlPage<TRow> class
One page of rows.
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether at least one row follows this page.
final
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- offset → int
-
final
- requestedRows → int
-
How many rows were asked for, which is not how many came back.
final
-
rows
→ List<
TRow> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int?
-
Null unless
page(total: true)asked for it.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited