MssqlRepository<TRow, TKey>.withKeyValues constructor
MssqlRepository<TRow, TKey>.withKeyValues (
- MssqlSession session, {
- required MssqlTableBinding<
TRow> binding, - required Map<
String, Object?> keyValues(- TKey key
- String? schema,
- String? table,
- MssqlDialect? dialect,
- MssqlScopeSelection scope = const MssqlScopeSelection.empty(),
- MssqlClock clock = MssqlClock.serverUtc,
- MssqlChangeHub? changes,
- MssqlCapabilityCache? capabilities,
- MssqlQueryOptions options = MssqlQueryOptions.defaults,
A repository over a table with a composite key needs to know how to take that key apart, which only generated code can say.
Implementation
MssqlRepository.withKeyValues(
this.session, {
required MssqlTableBinding<TRow> binding,
required Map<String, Object?> Function(TKey key) keyValues,
String? schema,
String? table,
this.dialect,
this.scope = const MssqlScopeSelection.empty(),
this.clock = MssqlClock.serverUtc,
this.changes,
this.capabilities,
this.options = MssqlQueryOptions.defaults,
}) : binding = binding.forTable(schema: schema, table: table),
_keyValues = keyValues;