What an expression is in SQL, as far as anything here can tell.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asNullable(
MssqlColumnType type) → MssqlColumnType -
typewith its nullability set, since an aggregate over no rows is null however the column it reads was declared. -
familyOf(
MssqlType type) → MssqlTypeFamily -
Which family
typebelongs to. -
of(
MssqlExpression expression) → MssqlColumnType? -
The SQL type of
expression, or null when it is not knowable.