monthStart method
This value snapped back to the first day of its month, as a date.
The axis of every monthly report, and named because that is what it is called; it is truncatedTo with MssqlTemporalGrain.month.
Implementation
MssqlExpression monthStart() =>
MssqlDateTruncate(this, MssqlTemporalGrain.month);