message property

  1. @override
String get message
override

A sentence naming what happened and, where there is one, what to do.

Implementation

@override
String get message =>
    '$source column "$column" was declared non-null but the row held '
    'SQL NULL. Remove the -- notnull override if the column can be null, '
    'or fix the query.';