MssqlWindow class

The OVER (…) clause: how the rows a window function reads are divided and ordered.

Annotations
  • @immutable

Constructors

MssqlWindow({Iterable<MssqlExpression> partitionBy = const <MssqlExpression>[], Iterable<MssqlOrder> orderBy = const <MssqlOrder>[], MssqlWindowFrame? frame})

Properties

frame → MssqlWindowFrame?
final
hashCode → int
The hash code for this object.
no setterinherited
orderBy → List<MssqlOrder>
final
partitionBy → List<MssqlExpression>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compile(MssqlParameterAllocator parameters, MssqlDialect dialect) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited