MssqlWindowFrame class

Defines the ROWS or RANGE visible to a window function.

An explicit frame avoids SQL Server's tie-sensitive default RANGE frame.

Annotations
  • @immutable

Constructors

MssqlWindowFrame({required MssqlFrameUnit unit, required MssqlFrameBound start, required MssqlFrameBound end})

Properties

end → MssqlFrameBound
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → MssqlFrameBound
final
unit → MssqlFrameUnit
final

Methods

compile(MssqlParameterAllocator parameters, MssqlDialect dialect) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited