withSession method
The same engine against another session, which a guard needs when it has to open a transaction of its own.
Implementation
MssqlWriteEngine<TRow> withSession(MssqlSession other) =>
MssqlWriteEngine<TRow>(
other,
binding: binding,
dialect: dialect,
triggers: triggers,
readback: readback,
changes: changes,
);