MssqlSelectQuery class abstract interface

A SELECT-shaped statement that can be nested while sharing parameters.

Implementers
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
projectionCount int?
Known number of selected expressions, or null when it cannot be proven.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compile({MssqlDialect dialect = MssqlDialect.sql2012}) MssqlStatement
compileInto(MssqlParameterAllocator parameters, MssqlDialect dialect, {bool nested = false}) String
get(MssqlSession session, {MssqlDialect dialect = MssqlDialect.sql2012, Duration? timeout, MssqlCancellationToken? cancellationToken, MssqlQueryOptions options = MssqlQueryOptions.defaults}) Future<List<MssqlRow>>

Available on MssqlSelectQuery, provided by the MssqlSelectQueryExecution extension

Every row, as the driver's own typed rows.
getAs<T>(MssqlSession session, T map(MssqlRow row), {MssqlDialect dialect = MssqlDialect.sql2012, Duration? timeout}) Future<List<T>>

Available on MssqlSelectQuery, provided by the MssqlSelectQueryExecution extension

Every row, mapped by map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
union(MssqlSelectQuery other) MssqlSetQuery
unionAll(MssqlSelectQuery other) MssqlSetQuery

Operators

operator ==(Object other) bool
The equality operator.
inherited