MssqlSetQuery class
A chain of UNION / UNION ALL queries with optional outer ordering.
- Implemented types
- Available extensions
- Annotations
-
- @immutable
Properties
-
allFlags
→ List<
bool> -
One flag per boundary between members. True means
UNION ALL.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
members
→ List<
MssqlSelectQuery> -
final
- offset → int?
-
final
-
ordering
→ List<
MssqlOrder> -
final
- projectionCount → int?
-
Known number of selected expressions, or null when it cannot be proven.
no setteroverride
- rows → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compile(
{MssqlDialect dialect = MssqlDialect.sql2012}) → MssqlStatement -
override
-
compileInto(
MssqlParameterAllocator parameters, MssqlDialect dialect, {bool nested = false}) → String -
override
-
get(
MssqlSession session, {MssqlDialect dialect = MssqlDialect.sql2012, Duration? timeout, MssqlCancellationToken? cancellationToken, MssqlQueryOptions options = MssqlQueryOptions.defaults}) → Future< List< MssqlRow> > -
Available on MssqlSelectQuery, provided by the MssqlSelectQueryExecution extension
Every row, as the driver's own typed rows. -
getAs<
T> (MssqlSession session, T map(MssqlRow row), {MssqlDialect dialect = MssqlDialect.sql2012, Duration? timeout}) → Future< List< T> > -
Available on MssqlSelectQuery, provided by the MssqlSelectQueryExecution extension
Every row, mapped bymap. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orderBy(
Iterable< MssqlOrder> terms) → MssqlSetQuery -
paged(
{required int offset, required int rows}) → MssqlSetQuery -
toString(
) → String -
A string representation of this object.
inherited
-
union(
MssqlSelectQuery other) → MssqlSetQuery -
override
-
unionAll(
MssqlSelectQuery other) → MssqlSetQuery -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited