compatibilityLevel property
The database's compatibility level, which can hold a modern server to an older set of behaviours and is therefore its own fact.
Implementation
final int compatibilityLevel;
The database's compatibility level, which can hold a modern server to an older set of behaviours and is therefore its own fact.
final int compatibilityLevel;