MssqlTriggerSchema class
A trigger, with the timing and events that decide what a write can read back.
- Annotations
-
- @immutable
Constructors
Properties
-
events
→ Set<
String> -
Some of
INSERT,UPDATE,DELETE.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isDisabled → bool
-
final
- isInsteadOf → bool
-
INSTEAD OFrather thanAFTER.final - name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited